@@ -26,7 +26,7 @@ class ShopResource:
         response = self.auth.request(endpoint)
         return Shop(**response)
     
-    def find_shops(self):
+    def find_shops(self, shop_name: str):
         """
         Find All Shops And Return Response Object
         
@@ -34,7 +34,7 @@ class ShopResource:
             Response: Return Response object of shop list 
         """
         endpoint = "shops/"
-        response = self.auth.request(endpoint)
+        response = self.auth.request(endpoint, params={"shop_name":shop_name})
         return Response[Shop](**response)
 
     def find_shop_by_owner_user_id(self, user_id: int):
